@@ -32,18 +32,7 @@
 class miri_source_c;
 typedef struct mirisdr_dev mirisdr_dev_t;
 
-/*
- * We use boost::shared_ptr's instead of raw pointers for all access
- * to gr::blocks (and many other data structures).  The shared_ptr gets
- * us transparent reference counting, which greatly simplifies storage
- * management issues.  This is especially helpful in our hybrid
- * C++ / Python system.
- *
- * See http://www.boost.org/libs/smart_ptr/smart_ptr.htm
- *
- * As a convention, the _sptr suffix indicates a boost::shared_ptr
- */
-typedef boost::shared_ptr<miri_source_c> miri_source_c_sptr;
+typedef std::shared_ptr<miri_source_c> miri_source_c_sptr;
 
 /*!
  * \brief Return a shared_ptr to a new instance of miri_source_c.
