@@ -38,7 +38,7 @@ class rfspace_source_c;
 #endif
 
 /*
- * We use boost::shared_ptr's instead of raw pointers for all access
+ * We use std::shared_ptr's instead of raw pointers for all access
  * to gr_blocks (and many other data structures).  The shared_ptr gets
  * us transparent reference counting, which greatly simplifies storage
  * management issues.  This is especially helpful in our hybrid
@@ -46,9 +46,9 @@ class rfspace_source_c;
  *
  * See http://www.boost.org/libs/smart_ptr/smart_ptr.htm
  *
- * As a convention, the _sptr suffix indicates a boost::shared_ptr
+ * As a convention, the _sptr suffix indicates a std::shared_ptr
  */
-typedef boost::shared_ptr<rfspace_source_c> rfspace_source_c_sptr;
+typedef std::shared_ptr<rfspace_source_c> rfspace_source_c_sptr;
 
 /*!
  * \brief Return a shared_ptr to a new instance of rfspace_source_c.
@@ -130,7 +130,8 @@ private: /* members */
     RFSPACE_SDR_IQ,
     RFSPACE_SDR_IP,
     RFSPACE_NETSDR,
-    RFSPACE_CLOUDIQ
+    RFSPACE_CLOUDIQ,
+    RFSPACE_CLOUDSDR
   };
 
   radio_type _radio;
