@@ -32,6 +32,8 @@
 class source_iface
 {
 public:
+  virtual ~source_iface() = default;
+
   /*!
    * Get the number of channels the underlying radio hardware offers.
    * \return the number of available channels
@@ -43,6 +45,7 @@ public:
    *
    * \param seek_point	sample offset in file
    * \param whence	one of SEEK_SET, SEEK_CUR, SEEK_END (man fseek)
+   * \param chan	the channel index 0 to N-1
    * \return true on success
    */
   virtual bool seek( long seek_point, int whence, size_t chan = 0 ) { return false; }
@@ -210,6 +213,7 @@ public:
 
   /*!
    * Select the active antenna of the underlying radio hardware.
+   * \param antenna the antenna name
    * \param chan the channel index 0 to N-1
    * \return the actual antenna's name
    */
